"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setBaseUrl = exports.httpLogger = void 0;
const winston_1 = require("winston");
const { printf, combine, timestamp, colorize, label } = winston_1.format;
let baseUrl = '/';
const customFormat = printf(info => {
    const { level, message, timestamp, label, at } = info;
    const levelName = level.substring(5, 9).toUpperCase();
    const lvl = level.replace(levelName.toLowerCase(), levelName);
    return `[${timestamp}][${label}][${lvl}][@${at || baseUrl}]: ${message}`;
});
exports.httpLogger = (0, winston_1.createLogger)({
    format: combine(label({ label: 'HTTP' }), colorize(), timestamp(), customFormat),
    transports: [
        new winston_1.transports.Console(),
        new winston_1.transports.File({
            filename: 'logs/combined.log'
        }),
        new winston_1.transports.File({
            filename: 'logs/http.log'
        }),
        new winston_1.transports.File({
            level: 'error',
            filename: 'logs/http.errors.log'
        })
    ]
});
const setBaseUrl = (baseUrl) => {
    baseUrl = baseUrl;
};
exports.setBaseUrl = setBaseUrl;
exports.default = exports.httpLogger;
